# Copyright (c) Sunlight Labs, 2012 under the terms and conditions
# of the LICENSE file.

"""
.. module:: tumbledore
    :synopsis: A Lightweight Tumblelog App

Django-Tumbledore __init__ entry. Does little else than define an
appname and version.
"""

__appname__ = "tumbledore"
__version__ = "0.1.3"
